<?php
/*
Plugin Name: BBYOpen
Plugin URI: http://developer.bestbuy.com/
Description: This is a WordPress plugin that adds a BBYOpen widget to your WordPress installation. The widget can be configured to search Best Buy items to be embedded in your widget-enabled WordPress theme.
Version: 1.0
Author: Bust Out Solutions
Author URI: http://bustoutsolutions.com/
*/

class BBYOpen_Widget extends WP_Widget {
    
    function BBYOpen_Widget() {
        parent::WP_Widget(false, $name = 'BBYOpen');
    }

    function widget($args, $instance) {
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);
        $api_key     = esc_attr($instance['api_key'    ]);
        $pid         = esc_attr($instance['pid'        ]);
        $search      = esc_attr($instance['search'     ]);
        $max_results = esc_attr($instance['max_results']);
        $sort        = esc_attr($instance['sort'       ]);
        
        $widget_url_base = 'http://remix.bustoutlabs.com/widget';
        $output = $before_widget.$before_title.$title.$after_title.
        "
            <script src='$widget_url_base/jquery.js' type='text/javascript'></script>
            <script type='text/javascript'>bbyJQuery = $; $.noConflict(true)</script>
            <script src='$widget_url_base/remix-widget.js' type='text/javascript'></script>
            <style type='text/css'>
                /* Adjust widget CSS to better handle narrow layout: */
                .bby-header {
                    overflow: visible;
                }
                .bby-title {
                    display: block;
                    clear: left;
                }
            </style>
            <div class='bby-remixwidget'
                 bbyApiKey='$api_key'
                 bbyPID='$pid'
                 ".($search ? "bbyQuery='search=$search'" : '')."
                 bbyCount='$max_results'
                 bbySort='$sort'
                 style='width: 100%; margin: 0.5em 0; font-size: 80%'></div><a style='color:#999;font-size:11px;' href='http://wordpress.org/extend/plugins/best-buy-products-plugin/'>Get the Best Buy widget for your blog</a>
        "
        .$after_widget;
      
        echo $output;
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'      ] = strip_tags($new_instance['title'      ]);
        $instance['api_key'    ] = strip_tags($new_instance['api_key'    ]);
        $instance['pid'        ] = strip_tags($new_instance['pid'        ]);
        $instance['search'     ] = strip_tags($new_instance['search'     ]);
        $instance['max_results'] = strip_tags($new_instance['max_results']);
        $instance['sort'       ] = strip_tags($new_instance['sort'       ]);

        return $instance;
    }
    
    function text_field($key, $value, $title) {
        ?>
        <p>
            <label for="<?php echo $this->get_field_id($key); ?>">
                <?php _e($title); ?>
                <input class="widefat"
                       id="<?php echo $this->get_field_id($key); ?>"
                       name="<?php echo $this->get_field_name($key); ?>"
                       type="text"
                       value="<?php echo $value; ?>" />
            </label>
        </p>
        <?php
    }
    
    function select_field($key, $value, $title, $options) {
        ?>
        <p>
            <label for="<?php echo $this->get_field_id($key); ?>">
                <?php _e($title); ?>
                <select id="<?php echo $this->get_field_id($key); ?>"
                        name="<?php echo $this->get_field_name($key); ?>" >
                <?php
                foreach($options as $option_value => $option_title) {
                    echo "<option value='$option_value'";
                    if($value == $option_value)
                        echo " selected='selected'";
                    echo ">";
                    echo $option_title;
                    echo "</option>";
                }
                ?>
                </select>
            </label>
        </p>
        <?php
    }

    function form($instance) {
        $defaults = array('title' => 'BBYOpen', 'max_results' => 3);
        $instance = wp_parse_args((array) $instance, $defaults );
        
        $title       = esc_attr($instance['title'      ]);
        $api_key     = esc_attr($instance['api_key'    ]);
        $pid         = esc_attr($instance['pid'        ]);
        $search      = esc_attr($instance['search'     ]);
        $max_results = esc_attr($instance['max_results']);
        $sort        = esc_attr($instance['sort'       ]);
        
        $this->text_field('title', $title, 'Title:');
        $this->text_field('search', $search, 'Search for:');
        $this->select_field(
            'max_results', $max_results, 'Max results:',
            array(1 => 'Single item', 2 => 2, 3 => 3, 4 => 4, 5 => 5, 6 => 6, 7 => 7, 8 => 8, 9 => 9, 10 => 10));
        $this->select_field(
            'sort', $sort, 'Sort by:',
            array(
                'salesRankMediumTerm.asc' => 'Most Popular',
                'startDate.desc' => 'Most Recent'));
        $this->text_field('api_key', $api_key, 'API Key (required): <div style="float:right"><small><a href="http://remix.mashery.com/member/register">What\'s this?</a></small></div>');
        $this->text_field('pid', $pid, 'Affiliate ID (optional): <div style="float:right"><small><a href="http://www.bestbuy.com/site/regularCat%3Apcmcat198500050002/regularCat%3Apcmcat198500050002/pcmcat198500050002.c?id=pcmcat198500050002">What\'s this?</a></small></div>');
    }

}

add_action('widgets_init', 'widget_bbyopen_init');

function widget_bbyopen_init() {
    register_widget('BBYOpen_Widget');
}
